from abc import ABC, abstractmethod
from typing import TYPE_CHECKING, Optional

if TYPE_CHECKING:
    from pystac import Item


class ItemBackend(ABC):
    def __repr__(self) -> str:
        return f"<{self.__class__.__name__}>"

    @abstractmethod
    def item_exists(self, item: "Item") -> bool:
        ...

    @abstractmethod
    def register_item(self, item: "Item"):
        ...

    @abstractmethod
    def deregister_identifier(self, identifier: str) -> Optional[str]:
        ...


class PathBackend(ABC):
    def __repr__(self) -> str:
        return f"<{self.__class__.__name__}>"

    @abstractmethod
    def path_exists(self, path: str) -> bool:
        ...

    @abstractmethod
    def register_path(self, path: str):
        ...

    @abstractmethod
    def deregister_path(self, path: str) -> Optional[str]:
        ...
